changeset 4603:7b8063c2d589

Use the FLYSHeader instead of the MainMenu The MainMenu is obsolete now and got completely replaced by the FLYSHeader.
author Björn Ricks <bjoern.ricks@intevation.de>
date Fri, 30 Nov 2012 09:59:07 +0100
parents 33bb8bf3899a
children 488db475613d
files flys-client/src/main/java/de/intevation/flys/client/client/FLYS.java
diffstat 1 files changed, 6 insertions(+), 9 deletions(-) [+]
line wrap: on
line diff
--- a/flys-client/src/main/java/de/intevation/flys/client/client/FLYS.java	Fri Nov 30 09:57:56 2012 +0100
+++ b/flys-client/src/main/java/de/intevation/flys/client/client/FLYS.java	Fri Nov 30 09:59:07 2012 +0100
@@ -31,7 +31,6 @@
 import de.intevation.flys.client.client.ui.FLYSHeader;
 import de.intevation.flys.client.client.ui.FLYSView;
 import de.intevation.flys.client.client.ui.FLYSWorkspace;
-import de.intevation.flys.client.client.ui.MainMenu;
 import de.intevation.flys.client.client.ui.ProjectList;
 import de.intevation.flys.client.shared.model.Artifact;
 import de.intevation.flys.client.shared.model.Collection;
@@ -77,10 +76,7 @@
     protected CreateCollectionServiceAsync collectionService =
         GWT.create(CreateCollectionService.class);
 
-    /** The menu bar at the top of the application. */
-    protected MainMenu menu;
-
-    /** The content window. It takes the whole space beneath the menu bar. */
+    /** The content window. It takes the whole space beneath the header. */
     protected FLYSView view;
 
     /** The project list that displays the projects of the user. */
@@ -98,6 +94,8 @@
     /** This list is used to track the opened projects. */
     protected List<String> openProjects;
 
+    private FLYSHeader header;
+
 
     public static String getExceptionString(FLYSConstants msg, Throwable caught) {
         try {
@@ -131,11 +129,10 @@
         vertical.setWidth100();
         vertical.setHeight100();
 
-        menu = new MainMenu(this);
         view = new FLYSView();
+        header = new FLYSHeader(this);
 
-        vertical.addMember(new FLYSHeader());
-        vertical.addMember(menu);
+        vertical.addMember(header);
         vertical.addMember(view);
 
         vertical.draw();
@@ -158,7 +155,7 @@
                 GWT.log("Found a user. Set '"+ user.getName() + "'");
                 setCurrentUser(user);
 
-                menu.setCurrentUser(user);
+                header.setCurrentUser(user);
 
                 projectList = new ProjectList(FLYS.this, user);
                 workspace   = new FLYSWorkspace();

http://dive4elements.wald.intevation.org